==> stependous_0.81_src.zip: ddr_dwi_creator.cpp <==
// ddr_dwi_creator.cpp : Defines the class behaviors for the application.
//

#include "stdafx.h"
#include "ddr_dwi_creator.h"
#include "ddr_dwi_creatorDlg.h"
#include ".\ddr_dwi_creator.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif


// Cddr_dwi_creatorApp

BEGIN_MESSAGE_MAP(Cddr_dwi_creatorApp, CWinApp)
	ON_COMMAND(ID_HELP, CWinApp::OnHelp)
	ON_COMMAND(ID_ACCELERATOR_CTRLO, OnAcceleratorCtrlo)
	ON_COMMAND(ID_FILE_OPEN32771, OnFileOpen32771)
	ON_COMMAND(ID_OPTIONS_PLAYMETRONOMESOUND, OnOptionsPlaymetronomesound)
	ON_COMMAND(ID_MODE_TAPTEMPO, OnModeTaptempo)
	ON_COMMAND(ID_MODE_STEPDATAINPUT, OnModeStepdatainput)
	ON_COMMAND(ID_FILE_IMPORTDWIFILE, OnFileImportdwifile)
	ON_COMMAND(ID_FILE_SAVE32772, OnFileSave32772)
	ON_COMMAND(ID_FILE_SAVEAS, OnFileSaveas)
	ON_COMMAND(ID_ABOUTCMD, OnAboutcmd)
END_MESSAGE_MAP()


// Cddr_dwi_creatorApp construction

Cddr_dwi_creatorApp::Cddr_dwi_creatorApp()
{
	// TODO: add construction code here,
	// Place all significant initialization in InitInstance
}


// The one and only Cddr_dwi_creatorApp object

Cddr_dwi_creatorApp theApp;


// Cddr_dwi_creatorApp initialization

BOOL Cddr_dwi_creatorApp::InitInstance()
{
	// InitCommonControls() is required on Windows XP if an application
	// manifest specifies use of ComCtl32.dll version 6 or later to enable
	// visual styles.  Otherwise, any window creation will fail.
	InitCommonControls();

	CWinApp::InitInstance();

	AfxEnableControlContainer();

	// Standard initialization
	// If you are not using these features and wish to reduce the size
	// of your final executable, you should remove from the following
	// the specific initialization routines you do not need
	// Change the registry key under which our settings are stored
	// TODO: You should modify this string to be something appropriate
	// such as the name of your company or organization
	SetRegistryKey(_T("Local AppWizard-Generated Applications"));

	Cddr_dwi_creatorDlg dlg;
	m_pMainWnd = &dlg;
	INT_PTR nResponse = dlg.DoModal();
	if (nResponse == IDOK)
	{
		// TODO: Place code here to handle when the dialog is
		//  dismissed with OK
	}
	else if (nResponse == IDCANCEL)
	{
		// TODO: Place code here to handle when the dialog is
		//  dismissed with Cancel
	}

	// Since the dialog has been closed, return FALSE so that we exit the
	//  application, rather than start the application's message pump.
	return FALSE;
}

void Cddr_dwi_creatorApp::OnAcceleratorCtrlo()
{
	AfxMessageBox("file open") ;
}

void Cddr_dwi_creatorApp::OnFileOpen32771()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->OpenMusicFile() ;
}



void Cddr_dwi_creatorApp::OnOptionsPlaymetronomesound()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->m_bPlayMetronome = !((Cddr_dwi_creatorDlg*)m_pMainWnd)->m_bPlayMetronome ;
	CMenu *menu = ((Cddr_dwi_creatorDlg*)m_pMainWnd)->GetMenu() ;

	UINT state = menu->GetMenuState( ID_OPTIONS_PLAYMETRONOMESOUND, MF_BYCOMMAND ) ;

	if ( ((Cddr_dwi_creatorDlg*)m_pMainWnd)->m_bPlayMetronome  )
	{
		menu->CheckMenuItem(ID_OPTIONS_PLAYMETRONOMESOUND, MF_CHECKED | MF_BYCOMMAND);
		((Cddr_dwi_creatorDlg*)m_pMainWnd)->PlayStateChangeMediaplayer1( 0, 2 ) ;
	}
	else
		menu->CheckMenuItem(ID_OPTIONS_PLAYMETRONOMESOUND, MF_UNCHECKED | MF_BYCOMMAND);

}

void Cddr_dwi_creatorApp::OnModeTaptempo()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->InitMode( 1 ) ; 
	CMenu *menu = ((Cddr_dwi_creatorDlg*)m_pMainWnd)->GetMenu() ;

	menu->CheckMenuItem(ID_MODE_TAPTEMPO, MF_CHECKED | MF_BYCOMMAND);
	menu->CheckMenuItem(ID_MODE_STEPDATAINPUT, MF_UNCHECKED | MF_BYCOMMAND);

}

void Cddr_dwi_creatorApp::OnModeStepdatainput()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->InitMode( 2 ) ; 
	CMenu *menu = ((Cddr_dwi_creatorDlg*)m_pMainWnd)->GetMenu() ;

	menu->CheckMenuItem(ID_MODE_TAPTEMPO, MF_UNCHECKED | MF_BYCOMMAND);
	menu->CheckMenuItem(ID_MODE_STEPDATAINPUT, MF_CHECKED | MF_BYCOMMAND);
}

void Cddr_dwi_creatorApp::OnFileImportdwifile()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->ImportDWI() ;
}

void Cddr_dwi_creatorApp::OnFileSave32772()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->Save( FALSE ) ;
}

void Cddr_dwi_creatorApp::OnFileSaveas()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->Save( TRUE ) ;
}

void Cddr_dwi_creatorApp::OnAboutcmd()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->OnSysCommand( IDM_ABOUTBOX, 0 ) ;

}

==> stependous_0.82_src.zip: ddr_dwi_creator.cpp <==
// ddr_dwi_creator.cpp : Defines the class behaviors for the application.
//

#include "stdafx.h"
#include "ddr_dwi_creator.h"
#include "ddr_dwi_creatorDlg.h"
#include ".\ddr_dwi_creator.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif


// Cddr_dwi_creatorApp

BEGIN_MESSAGE_MAP(Cddr_dwi_creatorApp, CWinApp)
	ON_COMMAND(ID_HELP, CWinApp::OnHelp)
	ON_COMMAND(ID_ACCELERATOR_CTRLO, OnAcceleratorCtrlo)
	ON_COMMAND(ID_FILE_OPEN32771, OnFileOpen32771)
	ON_COMMAND(ID_OPTIONS_PLAYMETRONOMESOUND, OnOptionsPlaymetronomesound)
	ON_COMMAND(ID_MODE_TAPTEMPO, OnModeTaptempo)
	ON_COMMAND(ID_MODE_STEPDATAINPUT, OnModeStepdatainput)
	ON_COMMAND(ID_FILE_IMPORTDWIFILE, OnFileImportdwifile)
	ON_COMMAND(ID_FILE_SAVE32772, OnFileSave32772)
	ON_COMMAND(ID_FILE_SAVEAS, OnFileSaveas)
	ON_COMMAND(ID_ABOUTCMD, OnAboutcmd)
	ON_COMMAND(ID_OPTIONS_METRONOMESOUNDATEACHBEAT, OnOptionsMetronomesoundateachbeat)
	ON_COMMAND(ID_OPTIONS_METRONOMESOUNDONLYONSTEPARROWS, OnOptionsMetronomesoundonlyonsteparrows)
END_MESSAGE_MAP()


// Cddr_dwi_creatorApp construction

Cddr_dwi_creatorApp::Cddr_dwi_creatorApp()
{
	// TODO: add construction code here,
	// Place all significant initialization in InitInstance
}


// The one and only Cddr_dwi_creatorApp object

Cddr_dwi_creatorApp theApp;


// Cddr_dwi_creatorApp initialization

BOOL Cddr_dwi_creatorApp::InitInstance()
{
	// InitCommonControls() is required on Windows XP if an application
	// manifest specifies use of ComCtl32.dll version 6 or later to enable
	// visual styles.  Otherwise, any window creation will fail.
	InitCommonControls();

	CWinApp::InitInstance();

	AfxEnableControlContainer();

	// Standard initialization
	// If you are not using these features and wish to reduce the size
	// of your final executable, you should remove from the following
	// the specific initialization routines you do not need
	// Change the registry key under which our settings are stored
	// TODO: You should modify this string to be something appropriate
	// such as the name of your company or organization
	SetRegistryKey(_T("Local AppWizard-Generated Applications"));

	Cddr_dwi_creatorDlg dlg;
	m_pMainWnd = &dlg;
	INT_PTR nResponse = dlg.DoModal();
	if (nResponse == IDOK)
	{
		// TODO: Place code here to handle when the dialog is
		//  dismissed with OK
	}
	else if (nResponse == IDCANCEL)
	{
		// TODO: Place code here to handle when the dialog is
		//  dismissed with Cancel
	}

	// Since the dialog has been closed, return FALSE so that we exit the
	//  application, rather than start the application's message pump.
	return FALSE;
}

void Cddr_dwi_creatorApp::OnAcceleratorCtrlo()
{
	AfxMessageBox("file open") ;
}

void Cddr_dwi_creatorApp::OnFileOpen32771()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->OpenMusicFile() ;
}



void Cddr_dwi_creatorApp::OnOptionsPlaymetronomesound()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->m_bPlayMetronome = !((Cddr_dwi_creatorDlg*)m_pMainWnd)->m_bPlayMetronome ;
	CMenu *menu = ((Cddr_dwi_creatorDlg*)m_pMainWnd)->GetMenu() ;

	UINT state = menu->GetMenuState( ID_OPTIONS_PLAYMETRONOMESOUND, MF_BYCOMMAND ) ;

	if ( ((Cddr_dwi_creatorDlg*)m_pMainWnd)->m_bPlayMetronome  )
	{
		menu->CheckMenuItem(ID_OPTIONS_PLAYMETRONOMESOUND, MF_CHECKED | MF_BYCOMMAND);
		((Cddr_dwi_creatorDlg*)m_pMainWnd)->PlayStateChangeMediaplayer1( 0, 2 ) ;
	}
	else
		menu->CheckMenuItem(ID_OPTIONS_PLAYMETRONOMESOUND, MF_UNCHECKED | MF_BYCOMMAND);

}

void Cddr_dwi_creatorApp::OnModeTaptempo()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->InitMode( 1 ) ; 
	CMenu *menu = ((Cddr_dwi_creatorDlg*)m_pMainWnd)->GetMenu() ;

	menu->CheckMenuItem(ID_MODE_TAPTEMPO, MF_CHECKED | MF_BYCOMMAND);
	menu->CheckMenuItem(ID_MODE_STEPDATAINPUT, MF_UNCHECKED | MF_BYCOMMAND);

}

void Cddr_dwi_creatorApp::OnModeStepdatainput()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->InitMode( 2 ) ; 
	CMenu *menu = ((Cddr_dwi_creatorDlg*)m_pMainWnd)->GetMenu() ;

	menu->CheckMenuItem(ID_MODE_TAPTEMPO, MF_UNCHECKED | MF_BYCOMMAND);
	menu->CheckMenuItem(ID_MODE_STEPDATAINPUT, MF_CHECKED | MF_BYCOMMAND);
}

void Cddr_dwi_creatorApp::OnFileImportdwifile()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->ImportDWI() ;
}

void Cddr_dwi_creatorApp::OnFileSave32772()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->Save( FALSE ) ;
}

void Cddr_dwi_creatorApp::OnFileSaveas()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->Save( TRUE ) ;
}

void Cddr_dwi_creatorApp::OnAboutcmd()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->OnSysCommand( IDM_ABOUTBOX, 0 ) ;

}

void Cddr_dwi_creatorApp::OnOptionsMetronomesoundateachbeat()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->m_nMetronomeMode = 0 ;

	CMenu *menu = ((Cddr_dwi_creatorDlg*)m_pMainWnd)->GetMenu() ;

	menu->CheckMenuItem(ID_OPTIONS_METRONOMESOUNDONLYONSTEPARROWS, MF_UNCHECKED | MF_BYCOMMAND);
	menu->CheckMenuItem(ID_OPTIONS_METRONOMESOUNDATEACHBEAT, MF_CHECKED | MF_BYCOMMAND);
}

void Cddr_dwi_creatorApp::OnOptionsMetronomesoundonlyonsteparrows()
{
	((Cddr_dwi_creatorDlg*)m_pMainWnd)->m_nMetronomeMode = 1 ;

	CMenu *menu = ((Cddr_dwi_creatorDlg*)m_pMainWnd)->GetMenu() ;

	menu->CheckMenuItem(ID_OPTIONS_METRONOMESOUNDONLYONSTEPARROWS, MF_CHECKED | MF_BYCOMMAND);
	menu->CheckMenuItem(ID_OPTIONS_METRONOMESOUNDATEACHBEAT, MF_UNCHECKED | MF_BYCOMMAND);

}
